@@ -1,4 +1,4 @@
-Trajectory <- R6::R6Class("trajectory",
+Trajectory <- R6Class("trajectory",
   public = list(
     name = NA,
     verbose = NA,
@@ -17,41 +17,20 @@ Trajectory <- R6::R6Class("trajectory",
       invisible()
     },
 
-    subset = function(i) {
-      if (missing(i)) {
-        elems <- seq_len(length(self))
-      } else {
-        stopifnot(length(i) <= length(self))
-        if (is.null(i)) i <- 0
-        if (is.logical(i)) {
-          elems <- which(i)
-        } else if (is.character(i)) {
-          elems <- which(private$names %in% i)
-        } else if (is.numeric(i)) {
-          i <- i[!is.na(i)]
-          if (any(i < 0) && any(i > 0))
-            stop("only 0's may be mixed with negative subscripts")
-          i <- as.integer(i)
-          i <- i[i != 0]
-          if (any(i < 0))
-            elems <- seq_len(length(self))[i]
-          else elems <- i
-        } else stop("invalid subscript type '", typeof(i), "'")
-      }
-
+    subset = function(i, double=FALSE) {
+      parts <- private$get_parts(i, double)
       new <- private$clone2(deep = TRUE)
       ptrs <- NULL
       names <- NULL
       n_activities <- 0
-      if (length(elems)) {
-        ptrs <- sapply(elems, function(i) {
+      if (length(parts)) {
+        ptrs <- sapply(parts, function(i) {
           new_ptr <- activity_clone_(private$ptrs[[i]])
           n_activities <<- n_activities + activity_get_n_(new_ptr)
           new_ptr
         })
-        mapply(function(i, j) activity_chain_(i, j),
-               utils::head(ptrs, -1), utils::tail(ptrs, -1))
-        names <- private$names[elems]
+        mapply(function(i, j) activity_chain_(i, j), ptrs[-length(ptrs)], ptrs[-1])
+        names <- private$names[parts]
       }
       new$.__enclos_env__$private$ptrs <- ptrs
       new$.__enclos_env__$private$names <- names
@@ -59,6 +38,22 @@ Trajectory <- R6::R6Class("trajectory",
       new
     },
 
+    split = function() { lapply(seq_len(length(self)), self$subset) },
+
+    replace = function(i, value, double=FALSE) {
+      stopifnot(inherits(value, "trajectory"))
+      if (!length(self)) self
+      else {
+        parts <- private$get_parts(i, double)
+        verbose <- self$verbose
+        new <- self$split()
+        new[parts] <- value$split()
+        new <- join(new)
+        new$verbose <- verbose
+        new
+      }
+    },
+
     join = function(traj) {
       stopifnot(inherits(traj, "trajectory"))
       new <- self$clone()
@@ -74,6 +69,10 @@ Trajectory <- R6::R6Class("trajectory",
       new
     },
 
+    rep = function(times=1, length.out=NA, each=1) {
+      join(rep(self$split(), times, length.out, each))
+    },
+
     head = function() { private$ptrs[[1]] },
 
     tail = function() { private$ptrs[[length(self)]] },
@@ -343,6 +342,31 @@ Trajectory <- R6::R6Class("trajectory",
       self
     },
 
+    get_parts = function(i, double=FALSE) {
+      if (missing(i)) {
+        parts <- seq_len(length(self))
+      } else {
+        stopifnot(length(i) <= length(self))
+        if (is.null(i)) i <- 0
+        if (is.logical(i)) {
+          parts <- which(rep_len(i, length(self)))
+        } else if (is.character(i)) {
+          parts <- which(private$names %in% i)
+          if (double) parts <- parts[[1]]
+        } else if (is.numeric(i)) {
+          i <- i[!is.na(i)]
+          if (any(i < 0) && any(i > 0))
+            stop("only 0's may be mixed with negative subscripts")
+          i <- as.integer(i)
+          i <- i[i != 0]
+          if (any(i < 0))
+            parts <- seq_len(length(self))[i]
+          else parts <- i
+        } else stop("invalid subscript type '", typeof(i), "'")
+      }
+      parts
+    },
+
     clone2 = function(){},
     copy = function(deep=TRUE) { self$subset() }
   )
