@@ -1,19 +1,19 @@
 context("method chaining")
 
 test_that("trajectory's method chaining works", {
-  t0 <- create_trajectory() %>%
+  t0 <- trajectory() %>%
     seize("one", 1) %>%
     release("one", 1) %>%
     timeout(function() 1) %>%
-    branch(function() 1, T, create_trajectory() %>% timeout(function() 1)) %>%
+    branch(function() 1, T, trajectory() %>% timeout(function() 1)) %>%
     rollback(1) %>%
     seize("one", 1)
 
-  expect_is(t0, "simmer.trajectory")
+  expect_is(t0, "trajectory")
 })
 
 test_that("simmer's method chaining works", {
-  t0 <- create_trajectory() %>%
+  t0 <- trajectory() %>%
     timeout(function() 1)
 
   env <- simmer(verbose = TRUE) %>%
