@@ -5,25 +5,25 @@ test_that("a generator without a trajectory fails", {
 })
 
 test_that("a non-function dist fails", {
-  t0 <- create_trajectory()
+  t0 <- trajectory()
 
   expect_error(simmer(verbose = TRUE) %>% add_generator("customer", t0, 1))
 })
 
 test_that("an empty trajectory fails", {
-  t0 <- create_trajectory()
+  t0 <- trajectory()
 
   expect_error(simmer(verbose = TRUE) %>% add_generator("customer", t0, function() {}))
 })
 
 test_that("a dist that returns a non-numeric value fails", {
-  t0 <- create_trajectory() %>% timeout(1)
+  t0 <- trajectory() %>% timeout(1)
 
   expect_error(simmer(verbose = TRUE) %>% add_generator("customer", t0, function() {}) %>% step())
 })
 
 test_that("generates the expected amount", {
-  t0 <- create_trajectory() %>% timeout(1)
+  t0 <- trajectory() %>% timeout(1)
 
   env <- simmer(verbose = TRUE) %>%
     add_generator("customer", t0, at(c(0, 1, 2))) %>%
@@ -34,7 +34,7 @@ test_that("generates the expected amount", {
 })
 
 test_that("generators are reset", {
-  t <- create_trajectory() %>% timeout(1)
+  t <- trajectory() %>% timeout(1)
 
   expect_equal(3, simmer(verbose = TRUE) %>%
     add_generator("dummy", t, at(0, 1, 2)) %>%
@@ -44,12 +44,12 @@ test_that("generators are reset", {
 })
 
 test_that("preemptible < priority shows a warning", {
-  t <- create_trajectory() %>% timeout(0)
+  t <- trajectory() %>% timeout(0)
   expect_warning(simmer(verbose = TRUE) %>% add_generator("dummy", t, at(0), priority = 3, preemptible = 1))
 })
 
 test_that("arrivals are correctly monitored", {
-  a <- create_trajectory() %>%
+  a <- trajectory() %>%
     seize("res2", 1) %>%
     batch(1) %>%
     seize("res1", 1) %>%
@@ -58,12 +58,12 @@ test_that("arrivals are correctly monitored", {
     separate() %>%
     release("res2", 1)
 
-  b <- create_trajectory() %>%
+  b <- trajectory() %>%
     seize("res1", 1) %>%
     timeout(6) %>%
     release("res1", 1)
 
-  c <- create_trajectory() %>%
+  c <- trajectory() %>%
     seize("res1", 1) %>%
     timeout(1) %>%
     rollback(1, times = Inf)
